Record Class BooleanEvaluationResult
java.lang.Object
java.lang.Record
com.javaaidev.agenticpatterns.evaluatoroptimizer.BooleanEvaluationResult
- Record Components:
passed- Passed or not passedfeedback- Feedback if not passed
- All Implemented Interfaces:
EvaluationResult
public record BooleanEvaluationResult(boolean passed, @Nullable String feedback)
extends Record
implements EvaluationResult
Boolean evaluation result
-
Constructor Summary
ConstructorsConstructorDescriptionBooleanEvaluationResult(boolean passed, @Nullable String feedback) Creates an instance of aBooleanEvaluationResultrecord class. -
Method Summary
Modifier and TypeMethodDescriptionfinal booleanIndicates whether some other object is "equal to" this one.@Nullable Stringfeedback()Returns the value of thefeedbackrecord component.@Nullable StringFeedback of evaluationfinal inthashCode()Returns a hash code value for this object.booleanpassed()Returns the value of thepassedrecord component.final StringtoString()Returns a string representation of this record class.
-
Constructor Details
-
BooleanEvaluationResult
public BooleanEvaluationResult(@JsonPropertyDescription("If evaluation passed") boolean passed, @JsonPropertyDescription("Feedback of evaluation") @Nullable String feedback) Creates an instance of aBooleanEvaluationResultrecord class.
-
-
Method Details
-
getFeedback
Description copied from interface:EvaluationResultFeedback of evaluation- Specified by:
getFeedbackin interfaceEvaluationResult- Returns:
- feedback
-
toString
Returns a string representation of this record class. The representation contains the name of the class, followed by the name and value of each of the record components. -
hashCode
public final int hashCode()Returns a hash code value for this object. The value is derived from the hash code of each of the record components. -
equals
Indicates whether some other object is "equal to" this one. The objects are equal if the other object is of the same class and if all the record components are equal. Reference components are compared withObjects::equals(Object,Object); primitive components are compared with '=='. -
passed
@JsonPropertyDescription("If evaluation passed") public boolean passed()Returns the value of thepassedrecord component.- Returns:
- the value of the
passedrecord component
-
feedback
Returns the value of thefeedbackrecord component.- Returns:
- the value of the
feedbackrecord component
-