Record Class FinalizationStep.FinalizationInput<Req,GenIn,GenOut>
java.lang.Object
java.lang.Record
com.javaaidev.agenticpatterns.evaluatoroptimizer.FinalizationStep.FinalizationInput<Req,GenIn,GenOut>
- Enclosing interface:
FinalizationStep<Request,GenInput, GenOutput, Response>
-
Constructor Summary
ConstructorsConstructorDescriptionFinalizationInput(@Nullable Req request, @Nullable GenIn genInput, GenOut genOutput) Creates an instance of aFinalizationInputrecord class. -
Method Summary
Modifier and TypeMethodDescriptionfinal booleanIndicates whether some other object is "equal to" this one.@Nullable GenIngenInput()Returns the value of thegenInputrecord component.Returns the value of thegenOutputrecord component.final inthashCode()Returns a hash code value for this object.@Nullable Reqrequest()Returns the value of therequestrecord component.final StringtoString()Returns a string representation of this record class.
-
Constructor Details
-
FinalizationInput
Creates an instance of aFinalizationInputrecord class.- Parameters:
request- the value for therequestrecord componentgenInput- the value for thegenInputrecord componentgenOutput- the value for thegenOutputrecord component
-
-
Method Details
-
toString
Returns a string representation of this record class. The representation contains the name of the class, followed by the name and value of each of the record components. -
hashCode
public final int hashCode()Returns a hash code value for this object. The value is derived from the hash code of each of the record components. -
equals
Indicates whether some other object is "equal to" this one. The objects are equal if the other object is of the same class and if all the record components are equal. All components in this record class are compared withObjects::equals(Object,Object). -
request
Returns the value of therequestrecord component.- Returns:
- the value of the
requestrecord component
-
genInput
Returns the value of thegenInputrecord component.- Returns:
- the value of the
genInputrecord component
-
genOutput
Returns the value of thegenOutputrecord component.- Returns:
- the value of the
genOutputrecord component
-