Record Class OptimizationStep.OptimizationInput<GenIn,GenOut,ER>
java.lang.Object
java.lang.Record
com.javaaidev.agenticpatterns.evaluatoroptimizer.OptimizationStep.OptimizationInput<GenIn,GenOut,ER>
- Enclosing interface:
OptimizationStep<GenInput,GenOutput, ER extends EvaluationResult>
-
Constructor Summary
ConstructorsConstructorDescriptionOptimizationInput(@Nullable GenIn genInput, GenOut genOutput, ER evaluationResult) Creates an instance of aOptimizationInputrecord class. -
Method Summary
Modifier and TypeMethodDescriptionfinal booleanIndicates whether some other object is "equal to" this one.Returns the value of theevaluationResultrecord component.@Nullable GenIngenInput()Returns the value of thegenInputrecord component.Returns the value of thegenOutputrecord component.final inthashCode()Returns a hash code value for this object.final StringtoString()Returns a string representation of this record class.
-
Constructor Details
-
OptimizationInput
Creates an instance of aOptimizationInputrecord class.- Parameters:
genInput- the value for thegenInputrecord componentgenOutput- the value for thegenOutputrecord componentevaluationResult- the value for theevaluationResultrecord component
-
-
Method Details
-
toString
Returns a string representation of this record class. The representation contains the name of the class, followed by the name and value of each of the record components. -
hashCode
public final int hashCode()Returns a hash code value for this object. The value is derived from the hash code of each of the record components. -
equals
Indicates whether some other object is "equal to" this one. The objects are equal if the other object is of the same class and if all the record components are equal. All components in this record class are compared withObjects::equals(Object,Object). -
genInput
Returns the value of thegenInputrecord component.- Returns:
- the value of the
genInputrecord component
-
genOutput
Returns the value of thegenOutputrecord component.- Returns:
- the value of the
genOutputrecord component
-
evaluationResult
Returns the value of theevaluationResultrecord component.- Returns:
- the value of the
evaluationResultrecord component
-